@@ -6,6 +6,9 @@ import time
 # construct a function that loads my openai API key from home and then calls it
 def load_config():
     config_path = os.path.join(os.path.expanduser('~'), 'dt_config.json')
+    # if does not exist try .dt_config.json
+    if not os.path.exists(config_path):
+        config_path = os.path.join(os.path.expanduser('~'), '.dt_config.json')
     config = json.loads(open(config_path).read())   
     return config
 
